/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal        *
* Escape Offenses report file and create a SAS dataset.                                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\ussc_escape_public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = ussc_escape_public ;

DATA library.&dataset ;
INFILE datafile LRECL=447;
INPUT
   SENTTOT  1-8             USSCIDN  9-15            ACCAP  16-18          
   ACCTRESP  19-21          AGE  22-24               CAROFFAP  25-27       
   CRIMPTS  28-30           DISTRICT  31-33          MONSEX  34-36         
   NEWCIT  37-39            NEWEDUC  40-42           NEWRACE  43-45        
   NOCOMP  46-48            NOCOUNTS  49-51          NOUSTAT  52-54        
   OFFGUIDE  55-57          PRISDUM  58-60           SENTPTS  61-63        
   SENTRNGE  64-66          SOURCES  67-69           TOTCHPTS  70-72       
   XCRHISSR  73-75          XFOLSOR  76-78           PROBATN  79-82        
   GDLINEHI $ 83-87         FY  88-91                ESCROLE  92-94        
   SUPERVISION  95-97       UFORCE  98-100           TIMEFORC  101-103     
   FACILITYLEV  104-106     FENCE  107-109           CONFDATE DATE11.      
   LOCATE  121-123          NEWCRIME1  124-126       NEWCRIME2  127-129    
   NEWCRIME3  130-132       NEWCRIME4  133-135       NEWCRIME5  136-138    
   OTHCRIME  139-141        OTHTYPE1  142-144        OTHTYPE2  145-147     
   OTHTYPE3  148-150        OTHTYPE4  151-153        FALSENAME  154-156    
   NOARRIVAL  157-159       STAT18751  160-162       STAT18752  163-165    
   STAT18753  166-168       STAT18755  169-171       STAT18756  172-174    
   STAT18757  175-177       STAT281826  178-180      STAT282902  181-183   
   STAT184  184-186         STAT181071  187-189      STAT181072  190-192   
   STAT184082  193-195      STAT18371  196-198       STAT18912  199-201    
   ANYVIOLENTHX  202-204    CNTVIOLENTHX  205-207    P_HOMICIDE  208-210   
   P_RAPE  211-213          P_ROBBERY  214-216       P_ASSAULT  217-219    
   P_OTHVIOLENT  220-222    P_BURGLARY  223-225      P_LARCENY  226-228    
   P_FRAUD  229-231         P_OTHPROP  232-234       P_DRUGTRAFF  235-237  
   P_DRUGPOSS  238-240      P_OTHDRUG  241-243       P_WEAPON  244-246     
   P_DUI  247-249           P_IMMIG  250-252         P_PUBORDER  253-255   
   P_OTHER  256-258         P_TRAFFIC  259-261       P_ESCAPE  262-264     
   PREVIOUS_GDLINEHI $ 265-270   PREVIOUS_OFFTYPE2  271-273
   ESCAPEBOL  274-276       ANYFLIGHT  277-279       FIRSTSOC  280-282     
   SECONDSOC  283-285       THIRDSOC  286-288        FOURTHSOC  289-291    
   M_ESCSTATUS  292-299     M_ATRRC  300-307         M_UNTILRELEASE  308-315
   RRCSTAY  316-318         NEW_HOMICIDE  319-321    NEW_RAPE  322-324     
   NEW_ROBBERY  325-327     NEW_ASSAULT  328-330     NEW_OTHVIOLENT  331-333
   NEW_BURGLARY  334-336    NEW_LARCENY  337-339     NEW_FRAUD  340-342    
   NEW_OTHPROP  343-345     NEW_DRUGTRAFF  346-348   NEW_DRUGPOSS  349-351 
   NEW_OTHDRUG  352-354     NEW_WEAPON  355-357      NEW_DUI  358-360      
   NEW_IMMIG  361-363       NEW_PUBORDER  364-366    NEW_OTHER  367-369    
   NEW_TRAFFIC  370-372     NEW_ESCAPE  373-375      NEW_VIOLENT  376-378  
   OTH_HOMICIDE  379-381    OTH_RAPE  382-384        OTH_ROBBERY  385-387  
   OTH_ASSAULT  388-390     OTH_OTHVIOLENT  391-393   OTH_BURGLARY  394-396 
   OTH_LARCENY  397-399     OTH_FRAUD  400-402       OTH_OTHPROP  403-405  
   OTH_DRUGTRAFF  406-408   OTH_DRUGPOSS  409-411    OTH_OTHDRUG  412-414  
   OTH_WEAPON  415-417      OTH_DUI  418-420         OTH_IMMIG  421-423    
   OTH_PUBORDER  424-426    OTH_OTHER  427-429       OTH_TRAFFIC  430-432  
   OTH_ESCAPE  433-435      OTH_VIOLENT  436-438     ANYCRIME  439-441     
   CRIMEONESCAPE  442-444   SAMECRIME  445-447     ;                       

FORMAT
   CONFDATE DATE9.        ;
                      

LENGTH
   USSCIDN 6                ACCAP 3                  ACCTRESP 3            
   AGE 3                    CAROFFAP 3               CRIMPTS 3             
   DISTRICT 3               MONSEX 3                 NEWCIT 3              
   NEWEDUC 3                NEWRACE 3                NOCOMP 3              
   NOCOUNTS 3               NOUSTAT 3                OFFGUIDE 3            
   PRISDUM 3                SENTPTS 3                SENTRNGE 3            
   SOURCES 3                TOTCHPTS 3               XCRHISSR 3            
   XFOLSOR 3                PROBATN 3                FY 3                  
   ESCROLE 3                SUPERVISION 4            UFORCE 4              
   TIMEFORC 3               FACILITYLEV 4            FENCE 4               
   LOCATE 4                 NEWCRIME1 4              NEWCRIME2 3           
   NEWCRIME3 3              NEWCRIME4 3              NEWCRIME5 3           
   OTHCRIME 4               OTHTYPE1 3               OTHTYPE2 3            
   OTHTYPE3 3               OTHTYPE4 3               FALSENAME 4           
   NOARRIVAL 3              STAT18751 3              STAT18752 3           
   STAT18753 3              STAT18755 3              STAT18756 3           
   STAT18757 3              STAT281826 3             STAT282902 3          
   STAT184 3                STAT181071 3             STAT181072 3          
   STAT184082 3             STAT18371 3              STAT18912 3           
   ANYVIOLENTHX 3           CNTVIOLENTHX 3           P_HOMICIDE 3          
   P_RAPE 3                 P_ROBBERY 3              P_ASSAULT 3           
   P_OTHVIOLENT 3           P_BURGLARY 3             P_LARCENY 3           
   P_FRAUD 3                P_OTHPROP 3              P_DRUGTRAFF 3         
   P_DRUGPOSS 3             P_OTHDRUG 3              P_WEAPON 3            
   P_DUI 3                  P_IMMIG 3                P_PUBORDER 3          
   P_OTHER 3                P_TRAFFIC 3              P_ESCAPE 3            
   PREVIOUS_OFFTYPE2 3      ESCAPEBOL 3              ANYFLIGHT 3           
   FIRSTSOC 3               SECONDSOC 3              THIRDSOC 3            
   FOURTHSOC 3              RRCSTAY 3                NEW_HOMICIDE 3        
   NEW_RAPE 3               NEW_ROBBERY 3            NEW_ASSAULT 3         
   NEW_OTHVIOLENT 3         NEW_BURGLARY 3           NEW_LARCENY 3         
   NEW_FRAUD 3              NEW_OTHPROP 3            NEW_DRUGTRAFF 3       
   NEW_DRUGPOSS 3           NEW_OTHDRUG 3            NEW_WEAPON 3          
   NEW_DUI 3                NEW_IMMIG 3              NEW_PUBORDER 3        
   NEW_OTHER 3              NEW_TRAFFIC 3            NEW_ESCAPE 3          
   NEW_VIOLENT 3            OTH_HOMICIDE 3           OTH_RAPE 3            
   OTH_ROBBERY 3            OTH_ASSAULT 3            OTH_OTHVIOLENT 3      
   OTH_BURGLARY 3           OTH_LARCENY 3            OTH_FRAUD 3           
   OTH_OTHPROP 3            OTH_DRUGTRAFF 3          OTH_DRUGPOSS 3        
   OTH_OTHDRUG 3            OTH_WEAPON 3             OTH_DUI 3             
   OTH_IMMIG 3              OTH_PUBORDER 3           OTH_OTHER 3           
   OTH_TRAFFIC 3            OTH_ESCAPE 3             OTH_VIOLENT 3         
   ANYCRIME 3               CRIMEONESCAPE 3          SAMECRIME 3 ;

       

RUN ;
